diff -ru nrpe-2.0.original/common/config.h.in nrpe-2.0/common/config.h.in
--- nrpe-2.0.original/common/config.h.in	2003-06-20 01:05:39.000000000 +0100
+++ nrpe-2.0/common/config.h.in	2005-09-14 14:00:06.000000000 +0100
@@ -229,4 +229,8 @@
 #endif
 #endif
 
+#undef socklen_t
+
+#undef HAVE_GETOPT_LONG
+
 #endif
diff -ru nrpe-2.0.original/configure.in nrpe-2.0/configure.in
--- nrpe-2.0.original/configure.in	2003-09-09 03:52:37.000000000 +0100
+++ nrpe-2.0/configure.in	2005-09-14 14:00:35.000000000 +0100
@@ -27,7 +27,7 @@
 AC_HEADER_TIME
 AC_HEADER_SYS_WAIT
 AC_CHECK_HEADERS(ctype.h dirent.h errno.h fcntl.h getopt.h grp.h inttypes.h netdb.h pwd.h signal.h stdint.h strings.h string.h syslog.h unistd.h arpa/inet.h netinet/in.h sys/types.h sys/time.h sys/resource.h sys/wait.h sys/socket.h sys/stat.h)
-
+AC_CHECK_FUNCS(getopt_long)
 dnl Checks for typedefs, structures, and compiler characteristics.
 AC_C_CONST
 AC_STRUCT_TM
@@ -86,6 +86,45 @@
 AC_SUBST(SOCKETLIBS)
 AC_CHECK_FUNCS(strdup strstr strtoul initgroups)
 
+dnl socklen_t check - from curl
+AC_CHECK_TYPE([socklen_t], ,[
+      AC_MSG_CHECKING([for socklen_t equivalent])
+      AC_CACHE_VAL([curl_cv_socklen_t_equiv],
+      [  
+         # Systems have either "struct sockaddr *" or
+         # "void *" as the second argument to getpeername
+         curl_cv_socklen_t_equiv=
+         for arg2 in "struct sockaddr" void; do
+            for t in int size_t unsigned long "unsigned long"; do
+               AC_TRY_COMPILE([
+                  #ifdef HAVE_SYS_TYPES_H
+                  #include <sys/types.h>
+                  #endif 
+                  #ifdef HAVE_SYS_SOCKET_H
+                  #include <sys/socket.h>
+                  #endif
+                  
+                  int getpeername (int, $arg2 *, $t *);
+               ],[
+                  $t len;
+                  getpeername(0,0,&len);
+               ],[
+                  curl_cv_socklen_t_equiv="$t"
+                  break
+               ])
+            done
+         done
+
+         if test "x$curl_cv_socklen_t_equiv" = x; then
+            AC_MSG_ERROR([Cannot find a type to use in place of socklen_t])
+         fi
+      ])
+      AC_MSG_RESULT($curl_cv_socklen_t_equiv)
+      AC_DEFINE_UNQUOTED(socklen_t, $curl_cv_socklen_t_equiv,
+                        [type to use in place of socklen_t if not defined])],
+      [#include <sys/types.h>
+#include <sys/socket.h>])
+
 AC_MSG_CHECKING(for type of socket size)
 AC_TRY_COMPILE([#include <stdlib.h>
 #include <sys/types.h>
@@ -122,7 +161,7 @@
 if test x$check_for_ssl = xyes; then
 	AC_MSG_CHECKING(for SSL)
 	found_ssl=no
-	for dir in $ssl_inc_dir /usr/local/openssl /usr/local/ssl /usr/lib/ssl /usr/ssl /usr/pkg /usr/local /usr; do
+	for dir in $ssl_inc_dir /usr/local/openssl /usr/local/ssl /usr/lib/ssl /usr/ssl /usr/pkg /usr/local /usr /usr/freeware/lib/openssl ; do
 		ssldir="$dir"
 		if test -f "$dir/include/openssl/ssl.h"; then
 			found_ssl=yes
@@ -157,7 +196,8 @@
 		else
 			sslbin=$ssldir/bin/openssl
 		fi
-		$sslbin dhparam -out /dev/null -C 512 > src/dh.h
+		# awk to strip off meta data at bottom of dhparam output
+		$sslbin dhparam -C 512 | awk '/^-----/ {exit} {print}' > src/dh.h
 	fi
 
 	dnl RedHat 8.0 and 9.0 include openssl compiled with kerberos, so we must include header file
diff -ru nrpe-2.0.original/src/check_nrpe.c nrpe-2.0/src/check_nrpe.c
--- nrpe-2.0.original/src/check_nrpe.c	2003-09-09 03:52:37.000000000 +0100
+++ nrpe-2.0/src/check_nrpe.c	2005-09-14 14:00:06.000000000 +0100
@@ -308,7 +308,7 @@
 	int c=1;
 	int i=1;
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 	int option_index=0;
 	static struct option long_options[]={
 		{"host", required_argument, 0, 'H'},
@@ -330,7 +330,7 @@
 	snprintf(optchars,MAX_INPUT_BUFFER,"H:c:a:t:p:nhl");
 
 	while(1){
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 		c=getopt_long(argc,argv,optchars,long_options,&option_index);
 #else
 		c=getopt(argc,argv,optchars);
diff -ru nrpe-2.0.original/src/nrpe.c nrpe-2.0/src/nrpe.c
--- nrpe-2.0.original/src/nrpe.c	2003-09-09 03:52:37.000000000 +0100
+++ nrpe-2.0/src/nrpe.c	2005-09-14 14:00:06.000000000 +0100
@@ -1437,7 +1437,7 @@
 	int c=1;
 	int have_mode=FALSE;
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 	int option_index=0;
 	static struct option long_options[]={
 		{"config", required_argument, 0, 'c'},
@@ -1457,7 +1457,7 @@
 	snprintf(optchars,MAX_INPUT_BUFFER,"c:nidhl");
 
 	while(1){
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 		c=getopt_long(argc,argv,optchars,long_options,&option_index);
 #else
 		c=getopt(argc,argv,optchars);
